import "./Alert.css";
import { AriaLabelingProps, DomProps } from "../../shared";
import { ComponentProps, ElementType, ForwardedRef, MouseEvent, ReactNode } from "react";
export interface InnerAlertProps extends DomProps, AriaLabelingProps {
    /**
     * The style to use.
     */
    variant?: "confirmation" | "destructive" | "warning" | "negative";
    /**
     * The primary button label.
     */
    primaryButtonLabel: string;
    /**
     * Whether or not the primary button is disabled.
     */
    primaryButtonDisabled?: boolean;
    /**
     * The secondary button label.
     */
    secondaryButtonLabel?: string;
    /**
     * Whether or not the secondary button is disabled.
     */
    secondaryButtonDisabled?: boolean;
    /**
     * The cancel button label.
     */
    cancelButtonLabel?: string;
    /**
     * The button to focus by default when the alert open.
     */
    autoFocusButton?: "primary" | "secondary" | "cancel";
    /**
     * Called when the primary button is clicked.
     * @param {MouseEvent} event - React's original event.
     * @returns {void}
     */
    onPrimaryButtonClick?: (event: MouseEvent) => void;
    /**
     * Called when the secondary button is clicked.
     * @param {MouseEvent} event - React's original event.
     * @returns {void}
     */
    onSecondaryButtonClick?: (event: MouseEvent) => void;
    /**
     * Called when the cancel button is clicked.
     * @param {MouseEvent} event - React's original event.
     * @returns {void}
     */
    onCancelButtonClick?: (event: MouseEvent) => void;
    /**
      * The z-index of the alert.
      */
    zIndex?: number;
    /**
      * Additional props to render on the wrapper element.
      */
    wrapperProps?: Record<string, any>;
    /**
      * An HTML element type or a custom React element type to render as.
      */
    as?: ElementType;
    /**
      * React children.
      */
    children: ReactNode;
    /**
      * @ignore
      */
    forwardedRef: ForwardedRef<any>;
}
export declare function InnerAlert({ variant, primaryButtonLabel, primaryButtonDisabled, secondaryButtonLabel, secondaryButtonDisabled, cancelButtonLabel, autoFocusButton, onPrimaryButtonClick, onSecondaryButtonClick, onCancelButtonClick, zIndex, children, forwardedRef, ...rest }: InnerAlertProps): JSX.Element;
export declare const Alert: import("../../shared").OrbitComponent<HTMLElement, InnerAlertProps>;
export declare type AlertProps = ComponentProps<typeof Alert>;
