import "./Avatar.css";
import { createSizeAdapter, cssModule, forwardRef, isNil, isNilOrEmpty, isString, mergeProps, normalizeSize, slot } from "../../shared";
import { AsyncImage } from "../../image";
import { Box } from "../../box";
import { useMemo } from "react";
import { Text } from "../../typography";
import { jsx as _jsx } from "react/jsx-runtime";

function AvatarImage({
  name,
  src,
  retryCount,
  size,
  "aria-label": ariaLabel
}) {
  if (!isString(src)) {
    return (
      /*#__PURE__*/
      // @ts-ignore
      _jsx("img", {
        src: src,
        alt: name,
        className: "o-ui-avatar-image"
      })
    );
  }

  return /*#__PURE__*/_jsx(AsyncImage, {
    src: src,
    alt: name,
    retryCount: retryCount,
    className: "o-ui-avatar-image",
    children: /*#__PURE__*/_jsx(AvatarInitials, {
      name: name,
      size: size,
      "aria-label": ariaLabel
    })
  });
}

const O365InitialsColorsForName = ["#99B433", "#6BA5E7", "#E773BD", "#00A300", "#1E7145", "#FF0097", "#7E3878", "#603CBA", "#5E4B8B", "#00ABA9", "#2D89EF", "#2B5797", "#DA532C", "#B91D47"];

function AvatarInitials({
  name,
  size,
  "aria-label": ariaLabel
}) {
  const initials = useMemo(() => {
    const cleanName = name.replace(/\s+/g, " ").trim();
    const [firstName, lastName] = cleanName.split(" ");
    return !isNil(firstName) && !isNil(lastName) ? `${firstName.charAt(0)}${lastName.charAt(0)}` : firstName.charAt(0);
  }, [name]);
  const color = useMemo(() => {
    let hashCode = 0;

    for (let i = name.length - 1; i >= 0; i--) {
      const character = name.charCodeAt(i);
      const shift = i % 8;
      hashCode ^= (character << shift) + (character >> 8 - shift);
    }

    return O365InitialsColorsForName[hashCode % O365InitialsColorsForName.length];
  }, [name]);
  return /*#__PURE__*/_jsx(AvatarText, {
    size: size,
    style: {
      backgroundColor: color
    },
    role: "img",
    "aria-label": ariaLabel !== null && ariaLabel !== void 0 ? ariaLabel : name,
    children: initials
  });
}

const textSize = createSizeAdapter({
  "2xs": "xs",
  "xs": "xs",
  "sm": "sm",
  "md": "md",
  "lg": "lg",
  "xl": "xl",
  "2xl": "2xl"
});
export function AvatarText({
  size,
  as = "span",
  children,
  ...rest
}) {
  return /*#__PURE__*/_jsx(Text, { ...mergeProps(rest, {
      size: textSize(size),
      className: "o-ui-avatar-text",
      as
    }),
    children: children
  });
}
export function InnerAvatar({
  name,
  src,
  retryCount,
  size,
  "aria-label": ariaLabel,
  as = "div",
  forwardedRef,
  ...rest
}) {
  const content = !isNilOrEmpty(src) ? /*#__PURE__*/_jsx(AvatarImage, {
    name: name,
    src: src,
    retryCount: retryCount,
    size: size,
    "aria-label": ariaLabel
  }) : /*#__PURE__*/_jsx(AvatarInitials, {
    name: name,
    size: size,
    "aria-label": ariaLabel
  });
  return /*#__PURE__*/_jsx(Box, { ...mergeProps(rest, {
      className: cssModule("o-ui-avatar", normalizeSize(size)),
      as,
      ref: forwardedRef
    }),
    children: content
  });
}
export const Avatar = slot("avatar", forwardRef((props, ref) => /*#__PURE__*/_jsx(InnerAvatar, { ...props,
  forwardedRef: ref
})));
Avatar.displayName = "Avatar";