import "./Card.css";
import { Box } from "../../box";
import { cloneElement, useMemo } from "react";
import { Text } from "../../typography";
import { cssModule, forwardRef, isNil, isString, mergeProps, normalizeSize, slot, useSlots } from "../../shared";
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
export function InnerCard({
  orientation = "vertical",
  size,
  fluid,
  as = "section",
  children,
  forwardedRef,
  ...rest
}) {
  var _header$props, _header$props2;

  const {
    image,
    illustration,
    heading,
    header,
    content,
    button,
    "button-group": buttonGroup
  } = useSlots(children, useMemo(() => ({
    _: {
      required: ["heading", "content"]
    },
    image: null,
    illustration: {
      orientation: orientation === "horizontal" ? "vertical" : "horizontal",
      className: "o-ui-card-illustration"
    },
    heading: {
      className: "o-ui-card-heading",
      size: "xs",
      as: "span"
    },
    header: {
      className: "o-ui-card-header"
    },
    content: {
      className: "o-ui-card-content",
      as: Text
    },
    button: {
      className: "o-ui-card-button"
    },
    "button-group": {
      className: "o-ui-card-button-group"
    }
  }), [orientation]));
  const headerMarkup = isString(header === null || header === void 0 ? void 0 : (_header$props = header.props) === null || _header$props === void 0 ? void 0 : _header$props.children) ? /*#__PURE__*/cloneElement(header, {
    children: /*#__PURE__*/_jsx(Text, {
      children: header === null || header === void 0 ? void 0 : (_header$props2 = header.props) === null || _header$props2 === void 0 ? void 0 : _header$props2.children
    })
  }) : header;

  const imageMarkup = image && /*#__PURE__*/_jsx(Box, {
    className: "o-ui-card-image",
    children: image
  });

  const headerSectionMarkup = /*#__PURE__*/_jsxs(Box, {
    className: "o-ui-card-header-section",
    children: [heading, headerMarkup]
  });

  const footerSectionMarkup = (!isNil(button) || !isNil(buttonGroup)) && /*#__PURE__*/_jsxs(Box, {
    className: "o-ui-card-footer-section",
    children: [button, buttonGroup]
  });

  return /*#__PURE__*/_jsxs(Box, { ...mergeProps(rest, {
      className: cssModule("o-ui-card", orientation, !fluid && normalizeSize(size), fluid && "fluid"),
      as,
      ref: forwardedRef
    }),
    children: [imageMarkup, illustration, /*#__PURE__*/_jsxs(Box, {
      className: "o-ui-card-aside",
      children: [headerSectionMarkup, content, footerSectionMarkup]
    })]
  });
}
export const Card = slot("card", forwardRef((props, ref) => /*#__PURE__*/_jsx(InnerCard, { ...props,
  forwardedRef: ref
})));
Card.displayName = "Card";