import "./DateInput.css";
import { augmentElement, cssModule, forwardRef, isNil, mergeClasses, mergeProps, useControllableState, useEventCallback } from "../../shared";
import { Box } from "../../box";
import { ButtonPresets } from "./ButtonPresets";
import { useCallback, useImperativeHandle, useMemo, useRef } from "react";
import { InputGroup, useInputGroupProps } from "../../input-group";
import { MenuPresets } from "./MenuPresets";
import { TextInput } from "../../text-input";
import { areEqualDates, toMidnightDate } from "./date-utils";
import { useDateInput } from "./useDateInput";
import { wrappedInputPropsAdapter } from "../../input"; // Used to generate BoxProps instead of any in the auto-generated documentation
// eslint-disable-next-line @typescript-eslint/no-empty-interface

import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
import { Fragment as _Fragment } from "react/jsx-runtime";
const Input = forwardRef((props, ref) => {
  const [inputGroupProps, isInGroup] = useInputGroupProps();
  const {
    value,
    min,
    max,
    onChange,
    onDateChange,
    wrapperProps,
    className,
    style,
    ...rest
  } = mergeProps(props, wrappedInputPropsAdapter(inputGroupProps));
  const dateProps = useDateInput({
    value,
    min,
    max,
    onChange,
    onDateChange,
    forwardedRef: ref
  });
  return /*#__PURE__*/_jsx(TextInput, { ...mergeProps(rest, {
      wrapperProps: mergeProps(wrapperProps !== null && wrapperProps !== void 0 ? wrapperProps : {}, {
        className: mergeClasses(className, cssModule("o-ui-date-input", isInGroup && "in-group")),
        style
      })
    }, dateProps)
  });
});
export function InnerDateInput({
  value: valueProp,
  defaultValue,
  placeholder = "dd/mm/yyyy",
  onDateChange,
  presets,
  presetsVariant = "compact",
  fluid,
  wrapperProps,
  disabled,
  readOnly,
  className,
  style,
  as,
  forwardedRef,
  ...rest
}) {
  const [value, setValue] = useControllableState(valueProp, defaultValue, null);
  const containerRef = useRef();
  const inputRef = useRef();
  useImperativeHandle(forwardedRef, () => {
    // For presets, used the group container as the ref element.
    if (!isNil(presets)) {
      const element = containerRef.current;

      element.focus = () => {
        var _inputRef$current;

        (_inputRef$current = inputRef.current) === null || _inputRef$current === void 0 ? void 0 : _inputRef$current.focus();
      };

      return element;
    }

    return inputRef.current;
  });
  const applyDate = useCallback((event, newDate) => {
    if (!areEqualDates(value, newDate)) {
      setValue(newDate);

      if (!isNil(onDateChange)) {
        onDateChange(event, newDate);
      }
    }
  }, [onDateChange, value, setValue]);
  const handleDateChange = useEventCallback((event, newDate) => {
    applyDate(event, newDate);
  });
  const handleSelectPreset = useEventCallback((event, newIndex) => {
    const preset = presets[newIndex];

    if (!isNil(preset)) {
      applyDate(event, preset.date);
    }
  });
  const presetsProps = useMemo(() => {
    if (!isNil(presets)) {
      const selectedIndex = presets.findIndex(x => areEqualDates(toMidnightDate(x.date), toMidnightDate(value)));
      return {
        values: presets.map(x => x.text),
        selectedIndex: selectedIndex !== -1 ? selectedIndex : undefined,
        onSelectionChange: handleSelectPreset
      };
    }

    return null;
  }, [presets, value, handleSelectPreset]);

  const inputMarkup = /*#__PURE__*/_jsx(Input, { ...mergeProps(rest, {
      value,
      placeholder,
      onDateChange: handleDateChange,
      ref: inputRef
    })
  });

  if (!isNil(presetsProps)) {
    return presetsVariant === "compact" ? /*#__PURE__*/_jsxs(InputGroup, { ...mergeProps({
        disabled,
        readOnly,
        fluid,
        className,
        style,
        as,
        ref: containerRef
      }, wrapperProps !== null && wrapperProps !== void 0 ? wrapperProps : {}),
      children: [inputMarkup, /*#__PURE__*/_jsx(MenuPresets, { ...presetsProps
      })]
    }) : /*#__PURE__*/_jsxs(Box, { ...mergeProps({
        className: mergeClasses(className, cssModule("o-ui-date-input-button-presets", fluid && "fluid")),
        style,
        as,
        ref: containerRef
      }, wrapperProps !== null && wrapperProps !== void 0 ? wrapperProps : {}),
      children: [inputMarkup, !disabled && !readOnly && /*#__PURE__*/_jsx(ButtonPresets, { ...presetsProps
      })]
    });
  } // A fragment is wrapping the result to make this component work with react-docgen: https://github.com/reactjs/react-docgen/issues/336


  return /*#__PURE__*/_jsx(_Fragment, {
    children: augmentElement(inputMarkup, {
      disabled,
      readOnly,
      wrapperProps,
      fluid,
      className,
      style,
      as
    })
  });
}
export const DateInput = forwardRef((props, ref) => /*#__PURE__*/_jsx(InnerDateInput, { ...props,
  forwardedRef: ref
}));
DateInput.displayName = "DateInput";