import { Children, useCallback, useRef } from "react";
import { DialogTriggerContext } from "./DialogTriggerContext";
import { Overlay, useOverlayLightDismiss, useOverlayTrigger } from "../../overlay";
import { augmentElement, forwardRef, isNil, mergeProps, resolveChildren, useControllableState, useEventCallback } from "../../shared";
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
export function InnerDialogTrigger({
  open: openProp,
  defaultOpen,
  onOpenChange,
  dismissable = true,
  zIndex = 1,
  as = "div",
  children,
  forwardedRef,
  ...rest
}) {
  const [isOpen, setIsOpen] = useControllableState(openProp, defaultOpen, false);
  const dialogRef = useRef();
  const updateIsOpen = useCallback((event, newValue) => {
    setIsOpen(newValue);

    if (!isNil(onOpenChange)) {
      onOpenChange(event, newValue);
    }
  }, [onOpenChange, setIsOpen]);
  const open = useCallback(event => {
    updateIsOpen(event, true);
  }, [updateIsOpen]);
  const close = useCallback(event => {
    updateIsOpen(event, false);
  }, [updateIsOpen]);
  const [trigger, modal] = Children.toArray(resolveChildren(children, {
    close
  }));

  if (isNil(trigger) || isNil(modal)) {
    throw new Error("A dialog trigger must have exactly 2 children.");
  }

  const triggerProps = useOverlayTrigger(isOpen, {
    onShow: useEventCallback(event => {
      open(event);
    }),
    onHide: useEventCallback(event => {
      close(event);
    }),
    hideOnLeave: false
  });
  const overlayDismissProps = useOverlayLightDismiss(dialogRef, {
    onHide: useEventCallback(event => {
      updateIsOpen(event, false);
    }),
    hideOnEscape: isOpen,
    hideOnLeave: false,
    hideOnOutsideClick: isOpen && dismissable
  });
  const triggerMarkup = augmentElement(trigger, triggerProps);
  const dialogMarkup = augmentElement(modal, {
    dismissable,
    zIndex: zIndex + 1,
    ref: dialogRef
  });
  return /*#__PURE__*/_jsxs(DialogTriggerContext.Provider, {
    value: {
      isOpen,
      close
    },
    children: [triggerMarkup, /*#__PURE__*/_jsx(Overlay, { ...mergeProps(rest, {
        show: isOpen,
        zIndex,
        as,
        ref: forwardedRef
      }, overlayDismissProps),
      children: dialogMarkup
    })]
  });
}
export const DialogTrigger = forwardRef((props, ref) => /*#__PURE__*/_jsx(InnerDialogTrigger, { ...props,
  forwardedRef: ref
}));
DialogTrigger.displayName = "DialogTrigger";