import "./Illustration.css";
import { Box } from "../../box";
import { useMemo } from "react";
import { Text } from "../../typography";
import { cssModule, forwardRef, isNil, mergeProps, slot, useSlots } from "../../shared";
import { jsxs as _jsxs } from "react/jsx-runtime";
import { jsx as _jsx } from "react/jsx-runtime";

function useColor(color) {
  return useMemo(() => {
    if (!isNil(color)) {
      if (color.startsWith("rgb") || color.startsWith("hsl") || color.startsWith("#")) {
        return color;
      } else if (color.startsWith("--")) {
        return `var(${color})`;
      } else if (color.startsWith("alias") || color.startsWith("global")) {
        return `var(--o-ui-${color})`;
      }

      return `var(--o-ui-${color.startsWith("primary") ? "alias" : "global"}-${color})`;
    }
  }, [color]);
}

export function InnerIllustration({
  orientation = "horizontal",
  shape = "straight",
  color,
  as = "div",
  children,
  forwardedRef,
  ...rest
}) {
  const {
    image,
    heading,
    content
  } = useSlots(children, useMemo(() => ({
    _: {
      required: ["image"]
    },
    image: {
      className: "o-ui-illustration-image"
    },
    heading: {
      className: "o-ui-illustration-heading",
      size: "sm",
      as: "h3"
    },
    content: {
      className: "o-ui-illustration-content",
      as: Text
    }
  }), []));
  return /*#__PURE__*/_jsxs(Box, { ...mergeProps(rest, {
      className: cssModule("o-ui-illustration", orientation, shape),
      style: {
        backgroundColor: useColor(color)
      },
      as,
      ref: forwardedRef
    }),
    children: [image, heading, content]
  });
}
export const Illustration = slot("illustration", forwardRef((props, ref) => /*#__PURE__*/_jsx(InnerIllustration, { ...props,
  forwardedRef: ref
})));
Illustration.displayName = "Illustration";