import { forwardRef, isNil, mergeProps, slot, useMergedRefs } from "../../shared";
import { Box } from "../../box";
import { useCallback, useMemo } from "react";
import { jsx as _jsx } from "react/jsx-runtime";

function useColor(color) {
  return useMemo(() => {
    if (!isNil(color)) {
      if (color.startsWith("rgb") || color.startsWith("hsl") || color.startsWith("#")) {
        return color;
      } else if (color.startsWith("--")) {
        return `var(${color})`;
      } else if (color.startsWith("alias") || color.startsWith("global")) {
        return `var(--o-ui-${color})`;
      }

      return `var(--o-ui-${color.startsWith("primary") ? "alias" : "global"}-${color})`;
    }
  }, [color]);
}

export function InnerSvgImage({
  src,
  size,
  width,
  height,
  stroke,
  fill,
  "aria-label": ariaLabel,
  forwardedRef,
  ...rest
}) {
  const hideUseElement = useCallback(element => {
    if (!isNil(element)) {
      var _element$querySelecto;

      // Remove auto-generated title if available.
      const titleElement = element.querySelector("title");

      if (!isNil(titleElement)) {
        titleElement.remove();
      } // Hide content from screen readers.


      (_element$querySelecto = element.querySelector("use")) === null || _element$querySelecto === void 0 ? void 0 : _element$querySelecto.setAttribute("aria-hidden", "true");
      element.querySelectorAll("path").forEach(x => {
        x.setAttribute("aria-hidden", "true");
      });
    }
  }, []);
  const ref = useMergedRefs(forwardedRef, hideUseElement);
  return /*#__PURE__*/_jsx(Box, { ...mergeProps(rest, {
      width: width !== null && width !== void 0 ? width : size,
      height: height !== null && height !== void 0 ? height : size,
      style: {
        stroke: useColor(stroke),
        fill: useColor(fill)
      },
      // View https://www.scottohara.me/blog/2019/05/22/contextual-images-svgs-and-a11y.html#svgs-that-convey-information
      role: "img",
      focusable: false,
      as: src,
      "aria-label": ariaLabel,
      ref
    })
  });
}
export const SvgImage = slot("image", forwardRef((props, ref) => /*#__PURE__*/_jsx(InnerSvgImage, { ...props,
  forwardedRef: ref
})));
SvgImage.displayName = "SvgImage";