import "./Listbox.css";
import { Box } from "../../box";
import { useMemo } from "react";
import { Keys, cssModule, forwardRef, isNil, mergeProps, useEventCallback, useRefState, useSlots } from "../../shared";
import { OptionKeyProp } from "./Listbox";
import { Text } from "../../typography";
import { TooltipTrigger } from "../../tooltip";
import { useListboxContext } from "./ListboxContext"; // Used to generate CollectionItem instead of any in the auto-generated documentation
// eslint-disable-next-line @typescript-eslint/no-empty-interface

import { jsxs as _jsxs } from "react/jsx-runtime";
import { jsx as _jsx } from "react/jsx-runtime";
export function InnerListboxOption({
  item: {
    key,
    tooltip
  },
  id,
  disabled,
  active,
  focus,
  hover,
  as = "div",
  children,
  forwardedRef,
  ...rest
}) {
  var _text$props, _description$props;

  const {
    selectedKeys,
    onSelect,
    onFocus,
    focusManager,
    focusOnHover
  } = useListboxContext(); // TODO: should we use debouncing instead?

  const [hasMouseOverRef, setHasMouseOver] = useRefState(false);
  const handleClick = useEventCallback(event => {
    onSelect(event, key);
  }); // Hotfix for https://bugzilla.mozilla.org/show_bug.cgi?id=1487102

  const handleKeyUp = useEventCallback(event => {
    if (event.key === Keys.space) {
      event.preventDefault();
    }
  });
  const handleFocus = useEventCallback(event => {
    // Mouse over check to ensure we don't call the onFocus handler twice when focusOnHover is on.
    if (!hasMouseOverRef.current) {
      // Required for virtual focus.
      const activeElement = focusManager.focusKey(key);

      if (!isNil(onFocus)) {
        onFocus(event, key, activeElement);
      }
    }
  }); // Move focus to the option on mouse hover.

  const handleMouseEnter = useEventCallback(event => {
    setHasMouseOver(true);
    const activeElement = focusManager.focusKey(key);

    if (!isNil(onFocus)) {
      onFocus(event, activeElement.getAttribute(OptionKeyProp), activeElement);
    }
  });
  const handleMouseLeave = useEventCallback(() => {
    setHasMouseOver(false);
  });
  const {
    icon,
    avatar,
    text,
    description,
    "end-icon": endIcon
  } = useSlots(children, useMemo(() => ({
    _: {
      defaultWrapper: Text
    },
    icon: (_iconElement, slotElements) => {
      return {
        className: "o-ui-listbox-option-start-icon",
        size: isNil(slotElements.description) ? "sm" : "lg"
      };
    },
    avatar: (_avatarElement, slotElements) => {
      return {
        className: "o-ui-listbox-option-avatar",
        size: isNil(slotElements.description) ? "2xs" : "md"
      };
    },
    text: {
      id: `${id}-label`,
      className: "o-ui-listbox-option-label"
    },
    description: {
      id: `${id}-description`,
      className: "o-ui-listbox-option-description",
      size: "md"
    },
    "end-icon": {
      size: "sm",
      className: "o-ui-listbox-option-end-icon"
    }
  }), [id]));
  const labelId = text === null || text === void 0 ? void 0 : (_text$props = text.props) === null || _text$props === void 0 ? void 0 : _text$props.id;
  const descriptionId = description === null || description === void 0 ? void 0 : (_description$props = description.props) === null || _description$props === void 0 ? void 0 : _description$props.id;

  const optionMarkup = /*#__PURE__*/_jsxs(Box, { ...mergeProps(rest, {
      id,
      onClick: !disabled ? handleClick : undefined,
      onKeyUp: !disabled ? handleKeyUp : undefined,
      onFocus: !disabled ? handleFocus : undefined,
      onMouseEnter: !disabled && focusOnHover ? handleMouseEnter : undefined,
      onMouseLeave: !disabled ? handleMouseLeave : undefined,
      className: cssModule("o-ui-listbox-option", description && "has-description", focusOnHover && "no-hover", active && "active", focus && "focus", hover && "hover"),
      role: "option",
      [OptionKeyProp]: key,
      tabIndex: !disabled ? -1 : undefined,
      "aria-selected": !disabled && selectedKeys.includes(key),
      "aria-disabled": disabled,
      "aria-labelledby": labelId,
      "aria-describedby": description && descriptionId,
      as,
      ref: forwardedRef
    }),
    children: [icon, avatar, text, description, endIcon]
  });

  if (!isNil(tooltip)) {
    const {
      props: tooltipProps,
      content: tooltipContent
    } = tooltip;
    return /*#__PURE__*/_jsxs(TooltipTrigger, { ...mergeProps(tooltipProps, {
        position: "left"
      }),
      children: [optionMarkup, tooltipContent]
    });
  }

  return optionMarkup;
}
export const ListboxOption = forwardRef((props, ref) => /*#__PURE__*/_jsx(InnerListboxOption, { ...props,
  forwardedRef: ref
}));
ListboxOption.displayName = "ListboxOption";