import "./Message.css";
import { CheckIcon, InfoIcon, WarningIcon } from "../../icons";
import { useMemo } from "react";
import { Content } from "../../placeholders";
import { CrossButton } from "../../button";
import { StyleProvider, augmentElement, cssModule, forwardRef, isNil, mergeProps, useMergedRefs, useSlots } from "../../shared";
import { Text } from "../../typography";
import { Transition } from "../../transition";
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
const MessageContent = forwardRef(({
  as = "div",
  children,
  ...rest
}, ref) => {
  return /*#__PURE__*/_jsx(Text, { ...rest,
    as: as,
    ref: ref,
    children: /*#__PURE__*/_jsx(StyleProvider, {
      value: {
        link: {
          color: "inherit"
        },
        heading: {
          size: "2xs",
          className: "o-ui-message-title"
        }
      },
      children: children
    })
  });
});
const Role = {
  informative: "status",
  warning: "alert",
  positive: "status",
  negative: "alert"
};
const Icon = {
  informative: /*#__PURE__*/_jsx(InfoIcon, {}),
  warning: /*#__PURE__*/_jsx(WarningIcon, {}),
  positive: /*#__PURE__*/_jsx(CheckIcon, {}),
  negative: /*#__PURE__*/_jsx(InfoIcon, {})
};
export function InnerMessage({
  show = true,
  variant = "informative",
  onDismiss,
  role: roleProp,
  as = "div",
  children,
  forwardedRef,
  ...rest
}) {
  var _ref;

  const ref = useMergedRefs(forwardedRef);
  const {
    content,
    button
  } = useSlots(children, useMemo(() => ({
    _: {
      defaultWrapper: Content
    },
    content: {
      className: "o-ui-message-content",
      as: MessageContent
    },
    button: {
      variant: "ghost",
      color: "inherit",
      condensed: true,
      size: "sm",
      className: "o-ui-message-action"
    }
  }), []));
  const iconMarkup = augmentElement(Icon[variant], {
    className: "o-ui-message-icon"
  });

  const dismissMarkup = !isNil(onDismiss) && /*#__PURE__*/_jsx(CrossButton, {
    color: "inherit",
    onClick: onDismiss,
    size: "sm",
    className: "o-ui-message-dismiss",
    "aria-label": "Dismiss"
  });

  return /*#__PURE__*/_jsxs(Transition, { ...mergeProps(rest, {
      show,
      enter: "o-ui-fade-in",
      leave: "o-ui-fade-out",
      className: cssModule("o-ui-message", variant),
      role: (_ref = roleProp !== null && roleProp !== void 0 ? roleProp : Role[variant]) !== null && _ref !== void 0 ? _ref : "alert",
      as,
      ref
    }),
    children: [iconMarkup, content, button, dismissMarkup]
  });
}
export const Message = forwardRef((props, ref) => /*#__PURE__*/_jsx(InnerMessage, { ...props,
  forwardedRef: ref
}));
Message.displayName = "Message";