import "./Modal.css";
import { StyleProvider, augmentElement, forwardRef, getSlotKey, isNil, mergeProps, useSlots } from "../../shared";
import { Children, useMemo } from "react";
import { Content } from "../../placeholders";
import { Dialog } from "../../dialog";
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";

function useModalContentMarkup(content) {
  return useMemo(() => {
    const before = [];
    const cards = [];
    const after = [];
    let hasEncounteredCard = false;
    Children.forEach(content.props.children, (x, index) => {
      if (getSlotKey(x) === "card") {
        cards.push(augmentElement(x, {
          key: index,
          fluid: true,
          className: "o-ui-modal-choice"
        }));
        hasEncounteredCard = true;
      } else {
        if (hasEncounteredCard) {
          after.push(x);
        } else {
          before.push(x);
        }
      }
    });
    const hasCards = cards.length > 0;

    if (hasCards && cards.length !== 2) {
      throw new Error("A choice modal must have exactly 2 card components.");
    }

    return {
      hasCards,
      contentMarkup: /*#__PURE__*/_jsxs(Content, { ...content.props,
        children: [before, !hasCards ? undefined : /*#__PURE__*/_jsx(StyleProvider, {
          value: {
            button: {
              variant: "outline"
            }
          },
          children: /*#__PURE__*/_jsx("div", {
            className: "o-ui-modal-choice-container",
            children: cards
          })
        }), after]
      })
    };
  }, [content]);
}

export function InnerModal({
  fullscreen,
  dismissable = true,
  zIndex = 1,
  children,
  forwardedRef,
  ...rest
}) {
  const {
    image,
    illustration,
    header,
    heading,
    content,
    footer,
    button,
    "button-group": buttonGroup
  } = useSlots(children, useMemo(() => ({
    _: {
      required: ["heading", "content"]
    },
    image: null,
    illustration: null,
    heading: null,
    header: null,
    content: {
      className: "o-ui-modal-content"
    },
    footer: null,
    button: null,
    "button-group": null
  }), []));
  const {
    hasCards,
    contentMarkup
  } = useModalContentMarkup(content);
  const size = useMemo(() => {
    if (!isNil(image) || !isNil(illustration)) {
      return "md";
    }

    if (hasCards) {
      return "lg";
    }

    return fullscreen ? "fullscreen" : "sm";
  }, [fullscreen, image, illustration, hasCards]);
  return /*#__PURE__*/_jsxs(Dialog, { ...mergeProps(rest, {
      size,
      dismissable,
      zIndex,
      ref: forwardedRef
    }),
    children: [image, illustration, heading, header, contentMarkup, footer, button, buttonGroup]
  });
}
export const Modal = forwardRef((props, ref) => /*#__PURE__*/_jsx(InnerModal, { ...props,
  forwardedRef: ref
}));
Modal.displayName = "Modal";