import "./Popover.css";
import { forwardRef, isNil, isString, mergeProps, useAutoFocusChild, useEventCallback, useFocusManager, useFocusScope, useId, useMergedRefs, useSlots } from "../../shared";
import { Box } from "../../box";
import { cloneElement, useCallback, useMemo } from "react";
import { Text } from "../../typography";
import { useOverlayFocusRing, useTrapFocus } from "../../overlay";
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
export function InnerPopover({
  id,
  focus,
  "aria-label": ariaLabel,
  "aria-labelledby": ariaLabelledBy,
  as = "section",
  children,
  forwardedRef,
  ...rest
}) {
  var _heading$props, _footer$props, _footer$props2;

  const [focusScope, setFocusRef] = useFocusScope();
  const popoverRef = useMergedRefs(forwardedRef, setFocusRef);
  const focusManager = useFocusManager(focusScope);
  useTrapFocus(focusManager);
  useAutoFocusChild(focusManager, {
    canFocus: useCallback(element => {
      // Do not autofocus the popover itself.
      if (element === popoverRef.current) {
        return false;
      } // Do not autofocus a link.


      if ((element === null || element === void 0 ? void 0 : element.tagName) === "A") {
        return false;
      }

      return true;
    }, [popoverRef]),
    onNotFound: useEventCallback(() => {
      var _popoverRef$current;

      (_popoverRef$current = popoverRef.current) === null || _popoverRef$current === void 0 ? void 0 : _popoverRef$current.focus();
    })
  });
  const focusRingProps = useOverlayFocusRing({
    focus
  });
  const popoverId = useId(id, "o-ui-popover");
  const {
    heading,
    content,
    footer,
    button,
    "button-group": buttonGroup
  } = useSlots(children, useMemo(() => ({
    _: {
      required: ["heading", "content"]
    },
    heading: {
      id: `${popoverId}-heading`,
      size: "sm",
      as: "h3"
    },
    content: {
      className: "o-ui-popover-content",
      as: Text
    },
    footer: {
      className: "o-ui-popover-footer",
      as: "footer"
    },
    button: {
      className: "o-ui-popover-button",
      size: "sm"
    },
    "button-group": {
      className: "o-ui-popover-button-group",
      size: "sm"
    }
  }), [popoverId]));
  const headingId = heading === null || heading === void 0 ? void 0 : (_heading$props = heading.props) === null || _heading$props === void 0 ? void 0 : _heading$props.id;
  const footerMarkup = isString(footer === null || footer === void 0 ? void 0 : (_footer$props = footer.props) === null || _footer$props === void 0 ? void 0 : _footer$props.children) ? /*#__PURE__*/cloneElement(footer, {
    children: /*#__PURE__*/_jsx(Text, {
      children: footer === null || footer === void 0 ? void 0 : (_footer$props2 = footer.props) === null || _footer$props2 === void 0 ? void 0 : _footer$props2.children
    })
  }) : footer;

  const headerSectionMarkup = heading && /*#__PURE__*/_jsx("header", {
    className: "o-ui-popover-header-section",
    children: heading
  });

  const footerSectionMarkup = (footer || button || buttonGroup) && /*#__PURE__*/_jsxs("footer", {
    className: "o-ui-popover-footer-section",
    children: [footerMarkup, button, buttonGroup]
  });

  return /*#__PURE__*/_jsxs(Box, { ...mergeProps(rest, {
      id,
      className: "o-ui-popover",
      tabIndex: -1,
      role: "dialog",
      "aria-label": ariaLabel,
      "aria-labelledby": isNil(ariaLabel) ? ariaLabelledBy !== null && ariaLabelledBy !== void 0 ? ariaLabelledBy : headingId : undefined,
      as,
      ref: popoverRef
    }, focusRingProps),
    children: [headerSectionMarkup, content, footerSectionMarkup]
  });
}
export const Popover = forwardRef((props, ref) => /*#__PURE__*/_jsx(InnerPopover, { ...props,
  forwardedRef: ref
}));
Popover.displayName = "Popover";