import "./Tile.css";
import { Box } from "../../box";
import { cssModule, forwardRef, isNil, isNumber, mergeProps, useAutoFocus, useCheckableProps, useControllableState, useEventCallback, useMergedRefs } from "../../shared";
import { useTile } from "./useTile";
import { jsx as _jsx } from "react/jsx-runtime";
export function InnerTile(props) {
  const [checkableProps, isCheckable] = useCheckableProps(props);
  const {
    checked,
    defaultChecked,
    value,
    onChange,
    onCheck,
    autoFocus,
    active,
    orientation = "vertical",
    focus,
    hover,
    as = "button",
    children,
    forwardedRef,
    ...rest
  } = mergeProps(props, checkableProps);
  const [isChecked, setIsChecked] = useControllableState(checked, defaultChecked, false);
  const ref = useMergedRefs(forwardedRef);
  const handleClick = useEventCallback(event => {
    setIsChecked(!isChecked);

    if (!isNil(onCheck)) {
      onCheck(event, value);
    }

    if (!isNil(onChange)) {
      onChange(event, !isChecked);
    }
  });
  const {
    tileProps,
    markup
  } = useTile({
    variant: "checkable",
    active,
    orientation,
    focus,
    hover,
    children
  });
  useAutoFocus(ref, {
    isDisabled: !autoFocus,
    delay: isNumber(autoFocus) ? autoFocus : undefined
  });
  return /*#__PURE__*/_jsx(Box, { ...mergeProps(rest, {
      className: cssModule("o-ui-tile"),
      onClick: handleClick,
      value,
      [isCheckable ? "aria-checked" : "aria-pressed"]: isChecked,
      as,
      ref
    }, tileProps),
    children: markup
  });
}
export const Tile = forwardRef((props, ref) => /*#__PURE__*/_jsx(InnerTile, { ...props,
  forwardedRef: ref
}));
Tile.displayName = "Tile";